@@ -14,6 +14,12 @@ from ..reporter import exception_reporting
 from ..version import VERSION_STR
 
 
+def _dump_json_for_humans(obj, fp):
+    """Wrapper around ``json.dump`` with custom config"""
+    json.dump(obj, fp, indent='  ', sort_keys='True')
+    print(file=fp)  # i.e. trailing newline
+
+
 class MultiQueue:
     def __init__(self):
         self._push_count = 0
@@ -51,11 +57,11 @@ class MultiQueue:
 
     def pop(self):
         try:
-            _, _, atom = heapq.heappop(self._min_heap)
+            prority, _, atom = heapq.heappop(self._min_heap)
         except IndexError:
             raise IndexError('All queues are empty')
         del self._priority_of[atom]
-        return atom
+        return atom, prority
 
     def __iter__(self):
         for item in heapq.nsmallest(len(self._min_heap), self._min_heap):
@@ -88,7 +94,7 @@ class MultiQueue:
         temp_filename = f'{filename}.tmp'
 
         with open(temp_filename, 'w') as f:
-            json.dump(doc, f, indent='  ', sort_keys='True')
+            _dump_json_for_humans(doc, f)
 
         os.rename(temp_filename, filename)
 
@@ -115,9 +121,16 @@ def run_push(config):
 
 def run_pop(config):
     muq = MultiQueue.load(config.state_filename)
-    atom = muq.pop()
+    atom, priority = muq.pop()
     muq.save(config.state_filename)
-    print(atom)
+
+    doc = {
+        'atom': atom,
+        'priority': priority,
+        'version': 2,
+    }
+
+    _dump_json_for_humans(doc, sys.stdout)
 
 
 def run_show(config):
@@ -150,7 +163,7 @@ def parse_command_line(argv):
                         default=os.path.expanduser('~/.gentoo-build-queue.json'),
                         help='where to store state (default: "%(default)s")')
 
-    subparsers = parser.add_subparsers(title='sub-cli', dest='command')
+    subparsers = parser.add_subparsers(title='sub-cli', dest='command', required=True)
 
     push_command = subparsers.add_parser('push', description='Add atoms to the queue')
     push_command.add_argument('priority',
